@@ -46,6 +46,11 @@ SEXP xml_to_txt(Rcpp::CharacterVector vec, std::string type) {
 
     std::string tmp = Rcpp::as<std::string>(vec[i]);
 
+    if (tmp.compare("") == 0) {
+      res[i] = NA_STRING;
+      continue;
+    }
+
     pugi::xml_document doc;
     pugi::xml_parse_result result = doc.load_string(tmp.c_str(), pugi::parse_default | pugi::parse_ws_pcdata | pugi::parse_escapes);
 
