@@ -179,6 +179,65 @@ typedef struct {
   uint16_t unused : 13;
 } BrtWbPropFields;
 
+typedef struct {
+  uint8_t valType : 4;
+  uint8_t errStyle : 3;
+  bool unused : 1;
+  bool fAllowBlank : 1;
+  bool fSuppressCombo : 1;
+  uint8_t mdImeMode : 8;
+  bool fShowInputMsg : 1;
+  bool fShowErrorMsg : 1;
+  uint8_t typOperator : 4;
+  bool fDVMinFmla : 1; // only in 14
+  bool fDVMaxFmla : 1; // only in 14
+  uint8_t reserved : 6;
+} BrtDValFields;
+
+typedef struct {
+  uint16_t product : 15;
+  bool reserved : 1;
+} FRTVersionFields;
+
+typedef struct {
+  bool fRef : 1;
+  bool fSqref : 1;
+  bool fFormula : 1;
+  bool fRelID : 1;
+  uint32_t reserved : 28;
+} FRTHeaderFields;
+
+typedef struct {
+  uint8_t columns : 2;
+  uint8_t rowType : 5;
+  bool squareBracketSpace : 1;
+  bool commaSpace : 1;
+  bool unused : 1;
+  uint8_t type : 2;
+  bool invalid : 1;
+  bool nonresident : 1;
+  uint8_t reserved2 : 2;
+} PtgListFields;
+
+enum PtgRowType
+{
+  data = 0x00,
+  all = 0x01,         // #All
+  headers = 0x02,     // #Headers
+  data2 = 0x04,       // #Data
+  dataheaders = 0x06,
+  totals = 0x08,      // #Totals
+  datatotals = 0x0C,
+  current = 0x10      // #This Row
+};
+
+enum PtgDataType
+{
+  reference = 0x1,
+  value = 0x2,
+  array = 0x3
+};
+
 enum RgbExtra
 {
   PtgExtraArray = 0,
@@ -1015,7 +1074,7 @@ enum RecordTypes
   BrtBeginModelTimeGrouping = 2139,
   BrtEndModelTimeGrouping = 2140,
   BrtModelTimeGroupingCalcCol = 2141,
-  BrtUID = 3072,
+  BrtUID = 3072, /* No longer part of 2.3.2 By Number */
   BrtRevisionPtr = 3073,
   BrtBeginDynamicArrayPr = 4096,
   BrtEndDynamicArrayPr = 4097,
@@ -1037,7 +1096,23 @@ enum RecordTypes
   BrtBeginCalcFeatures = 5095,
   BrtEndCalcFeatures = 5096,
   BrtCalcFeature = 5097,
-  BrtExternalLinksPr = 5099
+  BrtExternalLinksPr = 5099,
+  BrtPivotCacheImplicitMeasureSupport = 5100,
+  BrtPivotFieldIgnorableAfter = 5101,
+  BrtPivotHierarchyIgnorableAfter = 5102,
+  BrtPivotDataFieldFutureData = 5103,
+  BrtPivotCacheRichData = 5105,
+  BrtExternalLinksAlternateUrls = 5108,
+  BrtBeginPivotVersionInfo = 5109,
+  BrtEndPivotVersionInfo = 5110,
+  BrtBeginCacheVersionInfo = 5111,
+  BrtEndCacheVersionInfo = 5112, /* possible typo in 2.3.2 By Number */
+  BrtPivotRequiredFeature = 5113,
+  BrtPivotLastUsedFeature = 5114,
+  BrtExternalCodeService = 5117,
+  BrtSXDIAggregation = 5130,
+  BrtPivotFieldFeatureSupportInfo = 5131,
+  BrtPivotCacheAutoRefresh = 5132
 };
 
 enum PtgTypes
@@ -1644,7 +1719,7 @@ std::string Ftab(const uint16_t val) {
   case	0x0059:	return "CALLER()";
   case	0x005A:	return "DEREF(%s)";
   case	0x005B:	return "WINDOWS";
-  case	0x005C:	return "SERIES";
+  case	0x005C:	return "SERIES"; /* no longer in 2.5.98.10 Ftab */
   case	0x005D:	return "DOCUMENTS";
   case	0x005E:	return "ACTIVE.CELL()";
   case	0x005F:	return "SELECTION()";
