@@ -426,10 +426,20 @@ test_that("wb_remove_timeline() is a wrapper", {
 })
 
 test_that("wb_add_formula() is a wrapper", {
-  wb <- wb_workbook()$add_worksheet(1)
+  wb <- wb_workbook()$add_worksheet()
   expect_wrapper("add_formula",    wb = wb, params = list(sheet = 1, x = "=TODAY()"))
 })
 
+test_that("wb_add_hyperlink() is a wrapper", {
+  wb <- wb_workbook()$add_worksheet()$add_data(x = "http://github.com/JanMarvin/openxlsx2")
+  expect_wrapper("add_hyperlink", wb = wb, params = list(sheet = 1, col_names = FALSE))
+})
+
+test_that("wb_remove_hyperlink() is a wrapper", {
+  wb <- wb_workbook()$add_worksheet()
+  expect_wrapper("remove_hyperlink", wb = wb)
+})
+
 test_that("wb_update_table() is a wrapper", {
   wb <- wb_workbook()$add_worksheet()$add_data_table(x = iris[1:10, ])
   expect_wrapper("update_table", wb = wb, params = list(sheet = 1, tabname = "Table1", dims = "A1:D4"))
